/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.block;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.xwiki.rendering.listener.Listener;

/**
 * Represents a quotation. There are one or several quotation lines inside a quotation block.
 *
 * @version $Id: 8694b13dfc2f13a5b718a6f116b9887d02084475 $
 * @since 1.6M2
 */
public class QuotationBlock extends AbstractBlock
{
    /**
     * @param blocks the children of the quotation
     */
    public QuotationBlock(List<Block> blocks)
    {
        super(blocks, Collections.<String, String>emptyMap());
    }

    /**
     * @param blocks the children of the quotation
     * @param parameters the parameters of the quotation
     */
    public QuotationBlock(List<Block> blocks, Map<String, String> parameters)
    {
        super(blocks, parameters);
    }

    @Override
    public void before(Listener listener)
    {
        listener.beginQuotation(getParameters());
    }

    @Override
    public void after(Listener listener)
    {
        listener.endQuotation(getParameters());
    }
}
