/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.transformation.linkchecker.script;

import java.util.Collections;
import java.util.Map;

import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.rendering.transformation.linkchecker.LinkState;
import org.xwiki.rendering.transformation.linkchecker.LinkStateManager;
import org.xwiki.script.service.ScriptService;

/**
 * Provides access to the {@link LinkStateManager} for scripts.
 *
 * @version $Id: 2e773ad0ea9495820887ecc9fd9bb6cb35f3097a $
 * @since 3.3M1
 */
@Component
@Named("linkchecker")
@Singleton
public class LinkCheckerScriptService implements ScriptService
{
    /**
     * The state manager instance to give access to.
     */
    @Inject
    private LinkStateManager linkStateManager;

    /**
     * @return the checked link states, see {@link LinkStateManager}
     */
    public Map<String, Map<String, LinkState>> getLinkStates()
    {
        return Collections.unmodifiableMap(this.linkStateManager.getLinkStates());
    }
}
